@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 #@file: build.py
 #This script install Scribo project 
 #@author: Alexander Sannikov <sannikov@cs.karelia.ru>
@@ -10,7 +11,7 @@ from distutils.core import setup
 from src.About import __version__ as v
 version = v
 
-build = "934"
+build = "936"
 
 sh = ['scribo']
 desktop_file = ['scribo.desktop']
@@ -69,13 +70,9 @@ setup(
   description='Blogging client for Maemo',
   long_description="""
 Cross-Blog Client.
-This version is alpha; it is oriented to developers, not regular users.
 You can help the Scribo project if you try our application.
 Please send your comments to maemo-scribo@cs.karelia.ru
 and bugs to http://oss.fruct.org/bugzilla/.
-Note that the Scribo local cache can be changed in further releases.
-You MUST remove all application data from ~/.scribo before installing,
-e.g. with "rm -rf ~/.scribo".
 Thank you
 """,
   author="Zaiceva Dyana, Mezhenyn Artyom, Sannikov Alexander, Galov Ivan",
