@@ -611,6 +611,7 @@ class Message(Structure):
                 cur_list = Message.find(fetch_one = False, where = whr)
                 if cur_list:
                     list_post_filters.extend(cur_list)  
+        whr += " and type = "+str(POST)
         return list_post_filters     
         
     @staticmethod
@@ -632,6 +633,12 @@ class Message(Structure):
                 whr += 'journal='+str(poster[i])+' or '
             whr += 'journal='+str(poster[-1])+')'
 
+        #if there aren't conditions, so query will work correctly
+        if whr == "":
+            whr += " " +value
+
+        whr += " and type = "+str(POST)
+
         whr +=' ORDER BY '+value+" "+ sort
         print whr
         list_sort_msg = Message.find(fetch_one = False, where = whr)
@@ -736,7 +743,7 @@ class Message(Structure):
         if self.parent.misc[mark]==val:
             return True
             
-        
+        return self.parent._have_marked_parent(mark,val)
 
     
     
@@ -749,12 +756,14 @@ class Message(Structure):
         self.__mark_childs('frozen',False)
     
     def screen_childs(self):
-        self.__mark_childs('screened',True)
+        tmp = self.misc
+        tmp['screened'] = True
+        self.misc = tmp
         
     def unscreen_childs(self):
-        if self.have_screened_parent():
-            raise TypeError("Illegal message type", "Message have screened comments")
-        self.__mark_childs('screened',False)    
+        tmp = self.misc
+        tmp['screened'] = False
+        self.misc = tmp   
             
       
     def __mark_childs(self,field,flag):
@@ -770,4 +779,8 @@ class Message(Structure):
             i.__mark_childs(field,flag)
 
         
-    
\ No newline at end of file
+    def is_frozen(self):
+        return self.misc['frozen']
+
+    def is_screened(self):
+        return self.misc['screened']
