@@ -127,13 +127,13 @@
     </message>
     <message>
         <location filename="AddPost.py" line="601"/>
-        <source>The post is empty!</source>
-        <translation type="unfinished">Пост пустой!</translation>
+        <source>The text is empty!</source>
+        <translation type="unfinished">Поле с текстом не заполнено!</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="273"/>
-        <source>Do you want to send post with empty subject?</source>
-        <translation type="unfinished">Вы действительно хотите послать пост без темы?</translation>
+        <source>Do you want to send message with empty subject?</source>
+        <translation type="unfinished">Вы действительно хотите послать сообщение без темы?</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="304"/>
@@ -217,13 +217,14 @@
     </message>
     <message>
         <location filename="AddPost.py" line="508"/>
-        <source>Post will be lost! Continue? </source>
-        <translation type="unfinished">Пост будет утерян! Продолжить?</translation>
+        <source>Message will be lost! Continue? </source>
+        <translation type="unfinished">Сообщение будет утеряно! Продолжить?</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="582"/>
-        <source>Post was save</source>
-        <translation type="unfinished">Пост сохранен</translation>
+        <source>Post was save in drafts. See on main menu.</source>
+        <translation type="unfinished">Пост сохранен в черновиках. Смотрите в
+главном меню.</translation>
     </message>
 </context>
 <context>
