@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 """
 ===============================================================
@@ -19,7 +20,7 @@ from LivejAccount import LivejAccount
 
 DREAM_SERVER = "http://www.dreamwidth.org/interface/xmlrpc:80"
 DREAM_USERPICS = 'http://www.dreamwidth.org/userpic/'
-
+DREAM_SHORT = "http://www.dreamwidth.org"
 
 class DreamwAccount(LivejAccount):
 
@@ -50,3 +51,14 @@ class DreamwAccount(LivejAccount):
 
         return '../data/dreamw.png'
 
+    def refresh_comments (self, callback, addit = None):
+        pass
+
+    def screen_comment (self, msg, addit = None):
+        raise WarningExc("DreamAccount", "Operation not supported")
+
+    def freeze_comment (self, msg, addit = None):
+        raise WarningExc("DreamAccount", "Operation not supported")
+
+    def send_comment (self, msg, parent, addit = None):
+        raise WarningExc("DreamAccount", "Operation not supported")
\ No newline at end of file
