@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 """
 ===============================================================
@@ -19,7 +20,7 @@ from LivejAccount import LivejAccount
 
 INSANE_SERVER = "http://www.insanejournal.com/interface/xmlrpc:80"
 INSANE_USERPICS = 'http://www.insanejournal.com/userpic/'
-
+INSANE_JOURNAL = "http://www.insanejournal.com"
 
 class InsanejAccount(LivejAccount):
 
@@ -50,3 +51,15 @@ class InsanejAccount(LivejAccount):
 
         return '../data/insanej.gif'
 
+
+    def refresh_comments (self, callback, addit = None):
+        pass
+
+    def screen_comment (self, msg, addit = None):
+        raise WarningExc("InsanejAccount", "Operation not supported")
+
+    def freeze_comment (self, msg, addit = None):
+        raise WarningExc("InsanejAccount", "Operation not supported")
+
+    def send_comment (self, msg, parent, addit = None):
+        raise WarningExc("InsanejAccount", "Operation not supported")
\ No newline at end of file
