@@ -7,10 +7,8 @@ Class with test method for SqlDriver module
 """
 
 import sys
-sys.path.append("..")
-sys.path.append("../ldm")
 
-from SqlDriver import SqlDriver, sql_driver
+from ldm.SqlDriver import sql_driver
 import unittest
 
 
