@@ -55,7 +55,7 @@ class AddCommentWindow(AddPostWindow):
         """
 
         self.pict_act = QtGui.QToolButton(self.centr_widg)
-        self.pict_act.setIcon(QtGui.QIcon(self.tr("../data/en/image.png")))
+        self.pict_act.setIcon(QtGui.QIcon("../data/en/image.png"))
         self.pict_act.setText(self.tr("Add image"))
         self.pict_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.pict_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -63,7 +63,7 @@ class AddCommentWindow(AddPostWindow):
                      self.pict_post)
 
         self.other_act = QtGui.QToolButton(self.centr_widg)
-        self.other_act.setIcon(QtGui.QIcon(self.tr("../data/en/add_html.png")))
+        self.other_act.setIcon(QtGui.QIcon("../data/en/add_html.png"))
         self.other_act.setText(self.tr("HTML"))
         self.other_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.other_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -71,7 +71,7 @@ class AddCommentWindow(AddPostWindow):
                      self.other_post)
         """
         self.save_act = QtGui.QToolButton(self.centr_widg)
-        self.save_act.setIcon(QtGui.QIcon(self.tr("../data/en/save.png")))
+        self.save_act.setIcon(QtGui.QIcon("../data/en/save.png"))
         self.save_act.setText(self.tr("Save"))
         self.save_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.save_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -79,7 +79,7 @@ class AddCommentWindow(AddPostWindow):
                      self.save_post)
         """
         self.undo_act = QtGui.QToolButton(self.centr_widg)
-        self.undo_act.setIcon(QtGui.QIcon(self.tr("../data/en/undo.png")))
+        self.undo_act.setIcon(QtGui.QIcon("../data/en/undo.png"))
         self.undo_act.setText(self.tr("Undo"))
         self.undo_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.undo_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -87,7 +87,7 @@ class AddCommentWindow(AddPostWindow):
                      self.text_edit.undo)
 
         self.redo_act = QtGui.QToolButton(self.centr_widg)
-        self.redo_act.setIcon(QtGui.QIcon(self.tr("../data/en/redo.png")))
+        self.redo_act.setIcon(QtGui.QIcon("../data/en/redo.png"))
         self.redo_act.setText(self.tr("Redo"))
         self.redo_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.redo_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -95,7 +95,7 @@ class AddCommentWindow(AddPostWindow):
                      self.text_edit.redo)
 
         self.send_act = QtGui.QToolButton(self)
-        self.send_act.setIcon(QtGui.QIcon(self.tr("../data/en/send_post.png")))
+        self.send_act.setIcon(QtGui.QIcon("../data/en/send_post.png"))
         self.send_act.setText(self.tr("Send"))
         self.connect(self.send_act, QtCore.SIGNAL("clicked()"),
                          self.send_comment_ui)
