@@ -50,7 +50,7 @@ class AddPostWindow(MainWindow):
         self.hbox_all = QtGui.QHBoxLayout()
         self.hbox_title = QtGui.QHBoxLayout()        
 
-        title_label = QtGui.QLabel(self.tr("Subject"), self)
+        title_label = QtGui.QLabel(QtCore.QCoreApplication.translate("AddPostWindow","Subject"), self)
         title_label.setAlignment(QtCore.Qt.AlignLeft)
 
         self.text_edit = QtGui.QTextEdit(self)
@@ -61,8 +61,8 @@ class AddPostWindow(MainWindow):
         self.title_edit.setMaxLength(100)
 
         self.combo_view = QtGui.QComboBox(self.centr_widg)
-        self.combo_view.addItem(self.tr("Edit"))
-        self.combo_view.addItem(self.tr("Preview"))
+        self.combo_view.addItem(QtCore.QCoreApplication.translate("AddPostWindow","Edit"))
+        self.combo_view.addItem(QtCore.QCoreApplication.translate("AddPostWindow","Preview"))
         self.connect(self.combo_view,QtCore.SIGNAL("currentIndexChanged(int)"),
                          self.reload_edit)
         #if post will be edited
@@ -202,7 +202,7 @@ class AddPostWindow(MainWindow):
                          self.send_post)
         else:
             self.send_act.setIcon(QtGui.QIcon("../data/en/send_post.png"))
-            self.send_act.setText(self.tr("Send"))
+            self.send_act.setText(QtCore.QCoreApplication.translate("AddPostWindow","Send"))
             self.connect(self.send_act, QtCore.SIGNAL("clicked()"),
                          self.edit_post)
         self.send_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
@@ -223,13 +223,13 @@ class AddPostWindow(MainWindow):
 
         if (text_post == ""):
             ret = QtGui.QMessageBox.critical(self, self.tr("Scribo"),
-                               self.tr("The post is empty!"),
+                               QtCore.QCoreApplication.translate("AddPostWindow","The text is empty!"),
                                QtGui.QMessageBox.Ok)
             return
 
         if (self.title_edit.text() == ""):
             ret = QtGui.QMessageBox.question(self, self.tr("Scribo"),
-                               self.tr("Do you want to send post"\
+                               QtCore.QCoreApplication.translate("AddPostWindow","Do you want to send message"\
                                        " with empty subject?"),
                                QtGui.QMessageBox.Yes,
                                QtGui.QMessageBox.No)
@@ -323,11 +323,11 @@ class AddPostWindow(MainWindow):
         """
         msg = QtGui.QMessageBox()
         uri_edit = QtGui.QLineEdit(msg)
-        msg.setWindowTitle(self.tr("Add picture"))
-        title_label = QtGui.QLabel(self.tr("Link to the image (URL)"), msg)
+        msg.setWindowTitle(QtCore.QCoreApplication.translate("AddPostWindow","Add picture"))
+        title_label = QtGui.QLabel(QtCore.QCoreApplication.translate("AddPostWindow","Link to the image (URL)"), msg)
         msg.layout().addWidget(title_label, 0, 0)
         msg.layout().addWidget(uri_edit, 1, 0)
-        link_button = msg.addButton(self.tr("Add"),
+        link_button = msg.addButton(QtCore.QCoreApplication.translate("AddPostWindow","Add"),
                                     QtGui.QMessageBox.AcceptRole)
         cancel_button = msg.addButton(QtGui.QMessageBox.Abort)
         cancel_button.hide()
@@ -352,15 +352,15 @@ class AddPostWindow(MainWindow):
         @return 
         """
         msg = QtGui.QMessageBox()
-        msg.setWindowTitle(self.tr("Add link"))
+        msg.setWindowTitle(QtCore.QCoreApplication.translate("AddPostWindow","Add link"))
         uri_edit = QtGui.QLineEdit(msg)
         uri_edit.setFocus()
 
-        title_label = QtGui.QLabel(self.tr("Link"), msg)
+        title_label = QtGui.QLabel(QtCore.QCoreApplication.translate("AddPostWindow","Link"), msg)
         msg.layout().addWidget(title_label, 0, 0)
         msg.layout().addWidget(uri_edit, 1, 0)
 
-        link_button = msg.addButton(self.tr("Add"),
+        link_button = msg.addButton(QtCore.QCoreApplication.translate("AddPostWindow","Add"),
                                      QtGui.QMessageBox.AcceptRole)
         cancel_button = msg.addButton(QtGui.QMessageBox.Abort)
         cancel_button.hide()
@@ -388,24 +388,24 @@ class AddPostWindow(MainWindow):
         but_box.setOrientation(QtCore.Qt.Horizontal)
         but_box2.setOrientation(QtCore.Qt.Horizontal)
 
-        self.dial.setWindowTitle(self.tr("Add html tags"))
+        self.dial.setWindowTitle(QtCore.QCoreApplication.translate("AddPostWindow","Add html tags"))
         self.dial.setOrientation(QtCore.Qt.Horizontal)
 
-        self.bold_button = but_box.addButton(self.tr("Bold"),
+        self.bold_button = but_box.addButton(QtCore.QCoreApplication.translate("AddPostWindow","Bold"),
                                      QtGui.QDialogButtonBox.ActionRole)
-        self.italic_button = but_box.addButton(self.tr("Italic"),
+        self.italic_button = but_box.addButton(QtCore.QCoreApplication.translate("AddPostWindow","Italic"),
                                        QtGui.QDialogButtonBox.ActionRole)
-        self.center_button = but_box2.addButton(self.tr("Center"),
+        self.center_button = but_box2.addButton(QtCore.QCoreApplication.translate("AddPostWindow","Center"),
                                        QtGui.QDialogButtonBox.ActionRole)
-        self.right_button = but_box2.addButton(self.tr("Right"),
+        self.right_button = but_box2.addButton(QtCore.QCoreApplication.translate("AddPostWindow","Right"),
                                       QtGui.QDialogButtonBox.ActionRole)
-        self.left_button = but_box2.addButton(self.tr("Left"),
+        self.left_button = but_box2.addButton(QtCore.QCoreApplication.translate("AddPostWindow","Left"),
                                     QtGui.QDialogButtonBox.ActionRole)
-        self.just_button = but_box.addButton(self.tr("Justify"),
+        self.just_button = but_box.addButton(QtCore.QCoreApplication.translate("AddPostWindow","Justify"),
                                      QtGui.QDialogButtonBox.ActionRole)
-        self.color_button = but_box.addButton(self.tr("Color"),
+        self.color_button = but_box.addButton(QtCore.QCoreApplication.translate("AddPostWindow","Color"),
                                       QtGui.QDialogButtonBox.ActionRole)
-        self.link_button = but_box2.addButton(self.tr("Link"),
+        self.link_button = but_box2.addButton(QtCore.QCoreApplication.translate("AddPostWindow","Link"),
                                     QtGui.QDialogButtonBox.ActionRole)
 
         cancel_button = self.dial.addButton(QtGui.QMessageBox.Abort)
@@ -506,7 +506,7 @@ class AddPostWindow(MainWindow):
         res = QtGui.QMessageBox.No
         if self.title_edit.isModified() or self.start_text != text_post:
             res = QtGui.QMessageBox.question(self, self.tr("Scribo"),
-                               self.tr("Post will be lost! "\
+                               QtCore.QCoreApplication.translate("AddPostWindow","Message will be lost! "\
                                    "Continue? "),
                                QtGui.QMessageBox.Yes,
                                QtGui.QMessageBox.No)
@@ -580,7 +580,7 @@ class AddPostWindow(MainWindow):
         """ 
         self.add_in_drafts()
         ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                                                self.tr("Post was save"),
+                                                self.tr("Post was save in drafts. See on main menu."),
                                                 QtGui.QMessageBox.Yes)
         self.sending_post = True
         from ldm.Message import DRAFT
