@@ -117,10 +117,10 @@ class AddProfileWindow(MainWindow):
             self.del_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
             self.connect(self.del_act, QtCore.SIGNAL("clicked()"),
                          self.del_account_ui)
-            self.add_acc.setIcon(QtGui.QIcon(self.tr("../data/en/change_profile_ok.png")))
+            self.add_acc.setIcon(QtGui.QIcon("../data/en/change_profile_ok.png"))
             self.add_acc.setText(self.tr("OK"))
         else:
-            self.add_acc.setIcon(QtGui.QIcon(self.tr("../data/en/add_profile.png")))
+            self.add_acc.setIcon(QtGui.QIcon("../data/en/add_profile.png"))
             self.add_acc.setText(self.tr("Add account"))
 
         self.add_acc.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
