@@ -156,7 +156,7 @@ class ViewMessage(MainWindow):
                        <html xmlns="http://www.w3.org/1999/xhtml">\
                        <head><meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>\
                        <title>iframe</title>\
-                       <style type="text/css">HTML, BODY { background:transparent; padding:0; margin:0; border:0; overflow:hidden;}\
+                       <style type="text/css">HTML, BODY { background:transparent; padding:0; margin:0; border:0;}\
                        .scribo_stl {%s}\
                        .tags {font: 12pt; color: red; text-decoration:underline}\
                        .date {font-variant:small-caps; color: #e81f37;left: -12px;}\
